@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 MENUBAR
 MenuBar class to display menu title.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -49,6 +52,7 @@ _MODE_CLOSE = 1020
 _MODE_BACK = 1021
 
 
+# noinspection PyMissingOrEmptyDocstring
 class MenuBar(Widget):
     """
     MenuBar widget.
@@ -74,7 +78,7 @@ class MenuBar(Widget):
     :param args: Optional arguments for callbacks
     :type args: any
     :param kwargs: Optional keyword arguments for callbacks
-    :type kwargs: dict
+    :type kwargs: dict, any
     """
 
     def __init__(self,
@@ -103,6 +107,7 @@ class MenuBar(Widget):
         )
 
         self._backbox = back_box
+        self._backbox_border_width = 1  # px
         self._backbox_pos = None  # type: (tuple,None)
         self._backbox_rect = None  # type: (pygame.rect.Rect,None)
         self._background_color = background_color
@@ -125,6 +130,27 @@ class MenuBar(Widget):
     def scale(self, width, height, smooth=True):  # Widget don't support scalling (yet)
         pass
 
+    def get_title_offset(self):
+        """
+        Return the title offset in *(x, y)*.
+
+        :return: Title offset
+        :rtype: tuple
+        """
+        return self._offsetx, self._offsety
+
+    def set_backbox_border_width(self, width):
+        """
+        Set backbox border width in px.
+
+        :param width: Width in px
+        :type width: int
+        :return: None
+        """
+        assert isinstance(width, int)
+        assert width > 0
+        self._backbox_border_width = width
+
     # noinspection PyMissingOrEmptyDocstring
     def draw(self, surface):
         self._render()
@@ -142,7 +168,8 @@ class MenuBar(Widget):
             if self._box_mode == _MODE_CLOSE and self.get_menu()._onclose is None:
                 pass
             else:
-                pygame.draw.rect(surface, self._font_selected_color, self._backbox_rect, 1)
+                # noinspection PyArgumentList
+                pygame.draw.rect(surface, self._font_selected_color, self._backbox_rect, self._backbox_border_width)
                 pygame.draw.polygon(surface, self._font_selected_color, self._backbox_pos)
 
         surface.blit(self._surface,
@@ -163,7 +190,7 @@ class MenuBar(Widget):
         else:
             self._box_mode = _MODE_BACK
 
-        self._surface = self._render_string(self._title, self._font_selected_color, enable_fill=False)
+        self._surface = self._render_string(self._title, self._font_selected_color)
         self._rect.width, self._rect.height = self._surface.get_size()
         self._apply_surface_transforms()  # Rotation does not affect rect size
 
@@ -327,6 +354,8 @@ class MenuBar(Widget):
         self._title = to_string(title)
         self._offsety = offsety
         self._offsetx = offsetx
+        if self._menu is not None:
+            self._render()
 
     # noinspection PyMissingOrEmptyDocstring
     def update(self, events):
